@@ -1,5 +1,7 @@
 import requests
 
+from .__version__ import __version__
+
 
 class Client(object):
     """Client"""
@@ -7,17 +9,23 @@ class Client(object):
         self.auth_token = auth_token
         self.url = 'https://api.buttercms.com/v2/'
 
-    def api_get(self, params=None, slug=''):
+    def api_get(self, slug='', params=None):
         payload = {
             'auth_token': self.auth_token,
         }
         if params:
             payload.update(params)
+
+        headers = {
+            'X-Butter-Client': 'Python/{}'.format(__version__),
+        }
+
         response = requests.get(
             url=self.url + self.path + str(slug),
-            params=payload
+            params=payload,
+            headers=headers,
         )
         return response.json()
 
-    def get(self, slug=''):
-        return self.api_get(slug=slug)
+    def get(self, slug='', params=None):
+        return self.api_get(slug=slug, params=params)
